#! /usr/bin/python
# -*- coding: utf-8 -*-
#
# Ce fichier contient des fonctions utiles à l'ensemble des modules.

import random
from django.conf import settings
from django.shortcuts import render
from django.core.mail import send_mail
import string


def gen_str_alea(length):
    alphabet = string.ascii_letters + string.digits
    alea = ""

    for i in range(length):
        alea += random.choice(alphabet)

    return alea


def simplifier_mot(mot):
    tbl_repl = [
        ("éÉèÈêÊëË", "e"),
        ("àÀáÁâÂäÄãÃ", "a"),
        ("îÎïÏìÌíÍ]", "i"),
        ("ñÑ", "n"),
        ("çÇ", "c"),
        ("ôÔöÖòÒõÕóÓøØ", "o"),
        ("ÿÝý", "y"),
        ("ß", "ss"),
        ("ùÙûÛüÜúÚ", "u"),
        ("`'", ""),
    ]
    for (f, t) in tbl_repl:
        for c in f:
            if isinstance(mot, str):
                mot = mot.replace(c, t)
            else:
                mot = mot.replace(c.encode("utf8"), t)

    mot = mot.strip()
    mot = mot.lower()
    return mot


def mail_root(sujet, message):
    send_mail(
        sujet,
        message,
        settings.DEFAULT_FROM_EMAIL,
        ["root@bde.inp-toulouse.fr"],
        fail_silently=False,
    )


def confirmation(request, message, boutons, titre="Confirmation", parametres=[]):
    c = {
        "titre": titre,
        "message": message,
        "boutons": boutons,
        "type": "avert",
        "parametres": parametres,
    }

    return render(request, "message.html", c)


def erreur(request, message, titre="Erreur", statut=401):
    c = {
        "titre": titre,
        "message": message,
        "type": "err",
    }

    return render(request, "message.html", c, status=statut)


class lazy_property(object):
    def __init__(self, fget):
        self.fget = fget
        self.func_name = fget.__name__

    def __get__(self, obj, cls):
        if obj is None:
            return None

        value = self.fget(obj)
        setattr(obj, self.func_name, value)
        return value
